#include <Wire.h>
#include <LiquidCrystal_I2C.h>

// Initialize the I2C LCD with the I2C address (0x27 is a common address)
LiquidCrystal_I2C lcd(0x27, 16, 2);

// Define individual pins for the LEDs connected to the decade counter
const int ledPin1 = 8;
const int ledPin2 = 9;
const int ledPin3 = 10;
const int ledPin4 = 11;
const int ledPin5 = 12;
const int ledPin6 = 13;

// Define the button pin
const int buttonPin = 2;

void setup() {
  // Initialize the I2C LCD
  lcd.init();
  lcd.backlight();

  // Set all the LED pins as inputs
  pinMode(ledPin1, INPUT);
  pinMode(ledPin2, INPUT);
  pinMode(ledPin3, INPUT);
  pinMode(ledPin4, INPUT);
  pinMode(ledPin5, INPUT);
  pinMode(ledPin6, INPUT);

  // Set the button pin as input with pullup resistor
  pinMode(buttonPin, INPUT_PULLUP);
  
  // Print a message to the LCD.
  lcd.setCursor(0, 0);
  lcd.print("Dice Value:");
}

void loop() {
  static int lastDiceValue = 0;
  int currentDiceValue;

  // Check if the button is pressed
  if (digitalRead(buttonPin) == LOW) {
    // While the button is held down, update the LCD with the current dice value
    while (digitalRead(buttonPin) == LOW) {
      currentDiceValue = readDiceValue();
      if (currentDiceValue != lastDiceValue) {
        lastDiceValue = currentDiceValue;
        lcd.setCursor(0, 1);
        lcd.print("            ");  // Clear the line
        lcd.setCursor(0, 1);
        lcd.print(currentDiceValue);
      }
      delay(100); // Small delay to debounce and update the display
    }
    // When button is released, display the final dice value
    currentDiceValue = readDiceValue();
    lcd.setCursor(0, 1);
    lcd.print("            ");  // Clear the line
    lcd.setCursor(0, 1);
    lcd.print(currentDiceValue);
  }
}

int readDiceValue() {
  if (digitalRead(ledPin1) == HIGH) return 1;
  if (digitalRead(ledPin2) == HIGH) return 2;
  if (digitalRead(ledPin3) == HIGH) return 3;
  if (digitalRead(ledPin4) == HIGH) return 4;
  if (digitalRead(ledPin5) == HIGH) return 5;
  if (digitalRead(ledPin6) == HIGH) return 6;
  
  return 0; 
}
